function posneg = importfile(workbookFile, sheetName, dataLines)
%IMPORTFILE スプレッドシートからデータをインポート
%  POSNEG = IMPORTFILE(FILE) は、FILE という名前の Microsoft Excel スプレッドシート
%  ファイルの最初のワークシートからデータを読み取ります。  データを table として返します。
%
%  POSNEG = IMPORTFILE(FILE, SHEET) は、指定されたワークシートから読み取ります。
%
%  POSNEG = IMPORTFILE(FILE, SHEET, DATALINES)
%  は、指定されたワークシートから指定された行区間を読み取ります。DATALINES
%  を正の整数スカラーとして指定するか、行区間が不連続の場合は正の整数スカラーからなる N 行 2 列の配列として指定します。
%
%  例:
%  posneg = importfile("wordlist_posneg.xlsx", "Sheet2", [2, 5281]);
%
%  READTABLE も参照してください。
%
% MATLAB からの自動生成日: 2021/10/05 18:30:18

%% 入力の取り扱い

% シートが指定されていない場合、最初のシートを読み取ります
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% 行の始点と終点が指定されていない場合、既定値を定義します
if nargin <= 2
    dataLines = [2, 5281];
end

%% インポート オプションの設定およびデータのインポート
opts = spreadsheetImportOptions("NumVariables", 2);

% シートと範囲の指定
opts.Sheet = sheetName;
opts.DataRange = "A" + dataLines(1, 1) + ":B" + dataLines(1, 2);

% 列名と型の指定
opts.VariableNames = ["category", "word"];
opts.VariableTypes = ["categorical", "string"];

% 変数プロパティを指定
opts = setvaropts(opts, "word", "WhitespaceRule", "preserve");
opts = setvaropts(opts, ["category", "word"], "EmptyFieldRule", "auto");

% データのインポート
posneg = readtable(workbookFile, opts, "UseExcel", false);

for idx = 2:size(dataLines, 1)
    opts.DataRange = "A" + dataLines(idx, 1) + ":B" + dataLines(idx, 2);
    tb = readtable(workbookFile, opts, "UseExcel", false);
    posneg = [posneg; tb]; %#ok<AGROW>
end

end